@@ -2,6 +2,8 @@ package Mojo::Exception;
 use Mojo::Base -base;
 use overload bool => sub {1}, '""' => sub { shift->to_string }, fallback => 1;
 
+use Mojo::Util 'decode';
+
 has [qw(frames line lines_after lines_before)] => sub { [] };
 has message => 'Exception!';
 has 'verbose';
@@ -10,22 +12,22 @@ sub inspect {
   my ($self, @sources) = @_;
 
   # Extract file and line from message
-  my @trace;
+  my @files;
   my $msg = $self->lines_before([])->line([])->lines_after([])->message;
-  while ($msg =~ /at\s+(.+?)\s+line\s+(\d+)/g) { unshift @trace, [$1, $2] }
+  while ($msg =~ /at\s+(.+?)\s+line\s+(\d+)/g) { unshift @files, [$1, $2] }
 
   # Extract file and line from stack trace
-  if (my $zero = $self->frames->[0]) { push @trace, [$zero->[1], $zero->[2]] }
+  if (my $zero = $self->frames->[0]) { push @files, [$zero->[1], $zero->[2]] }
 
   # Search for context in files
-  for my $frame (@trace) {
-    next unless -r $frame->[0] && open my $handle, '<:utf8', $frame->[0];
-    $self->_context($frame->[1], [[<$handle>]]);
+  for my $file (@files) {
+    next unless -r $file->[0] && open my $handle, '<', $file->[0];
+    $self->_context($file->[1], [[<$handle>]]);
     return $self;
   }
 
   # Search for context in sources
-  $self->_context($trace[-1][1], [map { [split "\n"] } @sources]) if @sources;
+  $self->_context($files[-1][1], [map { [split "\n"] } @sources]) if @sources;
 
   return $self;
 }
@@ -46,6 +48,8 @@ sub to_string {
   return $str;
 }
 
+sub throw { CORE::die shift->new(shift)->trace(2)->inspect }
+
 sub trace {
   my ($self, $start) = (shift, shift // 1);
   my @frames;
@@ -55,6 +59,7 @@ sub trace {
 
 sub _append {
   my ($stack, $line) = @_;
+  $line = decode('UTF-8', $line) // $line;
   chomp $line;
   push @$stack, $line;
 }
@@ -96,7 +101,7 @@ Mojo::Exception - Exceptions with context
   use Mojo::Exception;
 
   # Throw exception and show stack trace
-  eval { die Mojo::Exception->new('Something went wrong!')->trace };
+  eval { Mojo::Exception->throw('Something went wrong!') };
   say "$_->[1]:$_->[2]" for @{$@->frames};
 
   # Customize exception
@@ -189,6 +194,15 @@ Render exception.
   # Render exception with context
   say $e->verbose(1)->to_string;
 
+=head2 throw
+
+  Mojo::Exception->throw('Something went wrong!');
+
+Throw exception from the current execution context.
+
+  # Longer version
+  die Mojo::Exception->new('Something went wrong!')->trace->inspect;
+
 =head2 trace
 
   $e = $e->trace;
