@@ -4,8 +4,6 @@ use Mojo::Base 'Mojo::Promise';
 # DEPRECATED!
 use base 'Mojo::EventEmitter';
 
-use Mojo::Util 'deprecated';
-
 sub begin {
   my ($self, $offset, $len) = @_;
   $self->{pending}++;
@@ -13,23 +11,8 @@ sub begin {
   return sub { $self->_step($id, $offset // 1, $len, @_) };
 }
 
-# DEPRECATED!
-sub data {
-  deprecated 'Mojo::IOLoop::Delay::data is DEPRECATED';
-  Mojo::Util::_stash(data => @_);
-}
-
 sub pass { $_[0]->begin->(@_) }
 
-# DEPRECATED!
-sub remaining {
-  deprecated 'Mojo::IOLoop::Delay::remaining is DEPRECATED';
-  my $self = shift;
-  return $self->{steps} ||= [] unless @_;
-  $self->{steps} = shift;
-  return $self;
-}
-
 sub steps {
   my ($self, @steps) = @_;
   $self->{steps} = \@steps;
@@ -150,7 +133,7 @@ that leads to the next closure in the series when executed.
   use Mojo::IOLoop;
 
   # Instead of nested closures we now have a simple chain of steps
-  my $delay = Mojo::IOloop->delay(
+  my $delay = Mojo::IOLoop->delay(
     sub {
       my $delay = shift;
       Mojo::IOLoop->timer(3 => $delay->begin);
